@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.04';
-$DATE = '2003/08/04';
+$VERSION = '0.05';
+$DATE = '2004/05/11';
 $FILE = __FILE__;
 
 ########
@@ -40,7 +40,7 @@ $FILE = __FILE__;
 
  Version: 
 
- Date: 2003/08/03
+ Date: 2004/05/11
 
  Prepared for: General Public 
 
@@ -90,6 +90,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      use File::Glob ':glob';
      use File::Copy;
      use File::Path;
+     use File::Spec;
      use File::Package;
      use File::SmartNL;
      use Text::Scrub;
@@ -97,6 +98,8 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      my $snl = 'File::SmartNL';
      my $fp = 'File::Package';
      my $s = 'Text::Scrub';
+     my $w = 'File::Where';
+     my $fs = 'File::Spec';
  ^
   N: UUT not loaded^
   A: $fp->is_package_loaded('ExtUtils::SVDmaker')^
@@ -122,11 +125,22 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      #
      unshift @INC, File::Spec->catdir( cwd(), 't');
      unshift @INC, File::Spec->catdir( cwd(), 'lib');
-     unlink File::Spec->catfile('lib','SVDtest1.pm'),File::Spec->catfile('lib', 'module1.pm');
-     unlink File::Spec->catfile('t','SVDtest1.t');
-     copy (File::Spec->catfile('expected','SVDtest0A.pm'),File::Spec->catfile('lib','SVDtest1.pm'));
-     copy (File::Spec->catfile('expected','module0A.pm'),File::Spec->catfile('lib','module1.pm'));
-     copy (File::Spec->catfile('expected','SVDtest0A.t'),File::Spec->catfile('t','SVDtest1.t'));
+     rmtree( 't' );
+     rmtree( 'lib' );
+     mkpath( 't' );
+     mkpath( 'lib' );
+     mkpath( $fs->catfile( 't', 'Test' ));
+     mkpath( $fs->catfile( 't', 'Data' ));
+     mkpath( $fs->catfile( 't', 'File' ));
+     copy ($fs->catfile('expected','SVDtest0A.pm'),$fs->catfile('lib','SVDtest1.pm'));
+     copy ($fs->catfile('expected','module0A.pm'),$fs->catfile('lib','module1.pm'));
+     copy ($fs->catfile('expected','SVDtest0A.t'),$fs->catfile('t','SVDtest1.t'));
+     copy ($fs->catfile('expected','SVDtest0A.t'),$fs->catfile('t','SVDtest1.t'));
+     copy ($fs->catfile('expected','Test','Tech.pm'),$fs->catfile('t','Test','Tech.pm'));
+     copy ($fs->catfile('expected','Data','Startup.pm'),$fs->catfile('t','Data','Startup.pm'));
+     copy ($fs->catfile('expected','Data','Secs2.pm'),$fs->catfile('t','Data','Secs2.pm'));
+     copy ($fs->catfile('expected','Data','SecsPack.pm'),$fs->catfile('t','Data','SecsPack.pm'));
+     copy ($fs->catfile('expected','File','Package.pm'),$fs->catfile('t','File','Package.pm'));
      rmtree 'packages';
  ^
  DO: ^
@@ -205,9 +219,9 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
 
 =head2 ok: 10
 
-  A: $s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) ))^
+  A: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) )))^
   N: generated ppd^
-  E: $s->scrub_date($snl->fin( File::Spec->catfile('expected','SVDtest2.ppd') ))^
+  E: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile('expected','SVDtest2.ppd') )))^
  ok: 10^
 
 =head2 ok: 11
@@ -299,9 +313,9 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
 
 =head2 ok: 19
 
-  A: $s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) ))^
+  A: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) )))^
   N: generated ppd^
-  E: $s->scrub_date($snl->fin( File::Spec->catfile( 'expected', 'SVDtest3.ppd') ))^
+  E: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'expected', 'SVDtest3.ppd') )))^
  ok: 19^
 
 =head2 ok: 20
@@ -418,20 +432,7 @@ Plain Old Documentation (POD)s
 =back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="EMAIL" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -459,6 +460,8 @@ Verify: SVDmaker.t^
     use File::Glob ':glob';
     use File::Copy;
     use File::Path;
+    use File::Spec;
+
     use File::Package;
     use File::SmartNL;
     use Text::Scrub;
@@ -467,6 +470,8 @@ Verify: SVDmaker.t^
     my $snl = 'File::SmartNL';
     my $fp = 'File::Package';
     my $s = 'Text::Scrub';
+    my $w = 'File::Where';
+    my $fs = 'File::Spec';
 ^
 
  N: UUT not loaded^
@@ -489,12 +494,23 @@ ok: 2^
     #
     unshift @INC, File::Spec->catdir( cwd(), 't');
     unshift @INC, File::Spec->catdir( cwd(), 'lib');
+    rmtree( 't' );
+    rmtree( 'lib' );
+    mkpath( 't' );
+    mkpath( 'lib' );
+    mkpath( $fs->catfile( 't', 'Test' ));
+    mkpath( $fs->catfile( 't', 'Data' ));
+    mkpath( $fs->catfile( 't', 'File' ));
 
-    unlink File::Spec->catfile('lib','SVDtest1.pm'),File::Spec->catfile('lib', 'module1.pm');
-    unlink File::Spec->catfile('t','SVDtest1.t');
-    copy (File::Spec->catfile('expected','SVDtest0A.pm'),File::Spec->catfile('lib','SVDtest1.pm'));
-    copy (File::Spec->catfile('expected','module0A.pm'),File::Spec->catfile('lib','module1.pm'));
-    copy (File::Spec->catfile('expected','SVDtest0A.t'),File::Spec->catfile('t','SVDtest1.t'));
+    copy ($fs->catfile('expected','SVDtest0A.pm'),$fs->catfile('lib','SVDtest1.pm'));
+    copy ($fs->catfile('expected','module0A.pm'),$fs->catfile('lib','module1.pm'));
+    copy ($fs->catfile('expected','SVDtest0A.t'),$fs->catfile('t','SVDtest1.t'));
+    copy ($fs->catfile('expected','SVDtest0A.t'),$fs->catfile('t','SVDtest1.t'));
+    copy ($fs->catfile('expected','Test','Tech.pm'),$fs->catfile('t','Test','Tech.pm'));
+    copy ($fs->catfile('expected','Data','Startup.pm'),$fs->catfile('t','Data','Startup.pm'));
+    copy ($fs->catfile('expected','Data','Secs2.pm'),$fs->catfile('t','Data','Secs2.pm'));
+    copy ($fs->catfile('expected','Data','SecsPack.pm'),$fs->catfile('t','Data','SecsPack.pm'));
+    copy ($fs->catfile('expected','File','Package.pm'),$fs->catfile('t','File','Package.pm'));
 
     rmtree 'packages';
 ^
@@ -562,9 +578,9 @@ ok: 8^
  E: $s->scrub_date($snl->fin( File::Spec->catfile('expected','README2') ))^
 ok: 9^
 
- A: $s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) ))^
+ A: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) )))^
  N: generated ppd^
- E: $s->scrub_date($snl->fin( File::Spec->catfile('expected','SVDtest2.ppd') ))^
+ E: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile('expected','SVDtest2.ppd') )))^
 ok: 10^
 
  A: -e File::Spec->catfile( 'packages', 'SVDtest1-0.01.tar.gz' )^
@@ -642,9 +658,9 @@ ok: 17^
  E: $s->scrub_date($snl->fin( File::Spec->catfile( 'expected', 'README3') ))^
 ok: 18^
 
- A: $s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) ))^
+ A: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'packages', 'SVDtest1.ppd' ) )))^
  N: generated ppd^
- E: $s->scrub_date($snl->fin( File::Spec->catfile( 'expected', 'SVDtest3.ppd') ))^
+ E: $s->scrub_architect($s->scrub_date($snl->fin( File::Spec->catfile( 'expected', 'SVDtest3.ppd') )))^
 ok: 19^
 
  A: -e File::Spec->catfile( 'packages', 'SVDtest1-0.01.tar.gz' )^
@@ -657,11 +673,10 @@ ok: 20^
     #####
     # Clean up
     #
-    unlink File::Spec->catfile('t','SVDtest1.t');
-    unlink File::Spec->catfile('lib','SVDtest1.pm'),File::Spec->catfile('lib', 'module1.pm');
-
     unlink 'SVDtest1.log';
+    unlink File::Spec->catfile('lib','SVDtest1.pm'),File::Spec->catfile('lib', 'module1.pm');
     rmtree 'packages';
+    rmtree 't';
 ^
 
 
@@ -736,24 +751,7 @@ ADVISED OF NEGLIGENCE OR OTHERWISE) ARISING IN
 ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 ^
 
-
-HTML:
-<hr>
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="EMAIL" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
-^
-
+HTML: ^
 
 
 ~-~
